/**
 * @filename:SalesCommodityService 2024-09-03
 * @project KJT v1.0.0 Copyright(c) 2024 wanglang Co. Ltd. All right reserved.
 */
package com.trade.service.trade.salescontract.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.trade.service.trade.salescontract.domain.SalesCommodity;
import com.trade.service.trade.salescontract.dto.SalesCommodityDto;
import com.trade.service.trade.salescontract.vo.SalesCommoditySearch;

import java.util.List;

/**
 * @Description:销售商品服务层
 * @version: v1.0.0
 * @author: wanglang
 */
public interface SalesCommodityService extends IService<SalesCommodity> {

    /**
     * 根据销售合同id查询销售商品
     *
     * @param salesContractId 销售合同id
     * @return 销售商品列表
     */
    List<SalesCommodity> queryBySalesContractId(Long salesContractId);

    /**
     * 根据销售合同id 和name查询销售商品
     * 
     * @param search
     * @return
     */
    List<SalesCommodity> getContractCommodityList(SalesCommoditySearch search);

    /**
     * 根据商品名称和客户id查询销售商品
     * 
     * @param name
     * @param xtUid
     * @param customerId
     * @param isImport
     * @return List<SalesCommodityDto>
     */
    List<SalesCommodityDto> getXiaoTuCommodityList(String name, String xtUid, Long customerId, boolean isImport);
}
